"""
Check if this EC2 instance should be the one and only to perform a task within
an auto-scaling group.
"""

import argparse
import logging

import chesney


def run_from_cli():
    """
    Perform an check instigated from a CLI.
    """

    arg_parser = argparse.ArgumentParser(
        description='Check if this EC2 instance should be the one and only '
                    'to perform a task within an auto-scaling group.',
        prog='python -m chesney')

    arg_parser.add_argument('--log-level',
                            default='CRITICAL',
                            help='Log level',
                            required=False)

    args = arg_parser.parse_args()

    logging.basicConfig(level=str(args.log_level).upper())
    log = logging.getLogger(__name__)

    try:
        is_appointed = chesney.is_appointed()
    except chesney.exceptions.NotRunningOnEC2Error as error:
        log.critical(error)
        exit(1)
    except chesney.exceptions.ClientError as error:
        log.critical(error)
        exit(2)

    print(str(is_appointed).lower())


if __name__ == '__main__':
    run_from_cli()
